# from Cython.Build import cythonize
from setuptools import setup


setup(name='Biomatters-Azimuth',
      version='0.2.5',
      author='Nicolo Fusi and Jennifer Listgarten',
      author_email="fusi@microsoft.com, jennl@microsoft.com",
      description=("Machine Learning-Based Predictive Modelling of CRISPR/Cas9 guide efficiency"),
      packages=["azimuth", "azimuth.features", "azimuth.models", "azimuth.tests"],
      package_data={'azimuth': ['saved_models/*.*', 'data/*.*', 'tests/*.*']},
      install_requires=['scipy==1.9.3', 'numpy==1.23.4', 'nose', 'scikit-learn==0.24.1', 'pandas==1.5.1', 'biopython==1.79', 'xlrd==2.0.1'],
      license="BSD",
      # ext_modules=cythonize("ssk_cython.pyx"),
      )
